==> zio-aws-networkmanager_2.13-5.17.150.1-sources.jar: zio/aws/networkmanager/model/AssociateConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateConnectPeerResponse(
    connectPeerAssociation: Option[
      zio.aws.networkmanager.model.ConnectPeerAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse = {
    import AssociateConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
      .builder()
      .optionallyWith(
        connectPeerAssociation.map(value => value.buildAwsValue())
      )(_.connectPeerAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.AssociateConnectPeerResponse
      .wrap(buildAwsValue())
}
object AssociateConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.AssociateConnectPeerResponse =
      zio.aws.networkmanager.model.AssociateConnectPeerResponse(
        connectPeerAssociation.map(value => value.asEditable)
      )
    def connectPeerAssociation
        : Option[zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly]
    def getConnectPeerAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "connectPeerAssociation",
      connectPeerAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ) extends zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly {
    override val connectPeerAssociation
        : Option[zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly] =
      scala
        .Option(impl.connectPeerAssociation())
        .map(value =>
          zio.aws.networkmanager.model.ConnectPeerAssociation.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ): zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-5.17.202.1-sources.jar: zio/aws/networkmanager/model/AssociateConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateConnectPeerResponse(
    connectPeerAssociation: Optional[
      zio.aws.networkmanager.model.ConnectPeerAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse = {
    import AssociateConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
      .builder()
      .optionallyWith(
        connectPeerAssociation.map(value => value.buildAwsValue())
      )(_.connectPeerAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.AssociateConnectPeerResponse
      .wrap(buildAwsValue())
}
object AssociateConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.AssociateConnectPeerResponse =
      zio.aws.networkmanager.model.AssociateConnectPeerResponse(
        connectPeerAssociation.map(value => value.asEditable)
      )
    def connectPeerAssociation
        : Optional[zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly]
    def getConnectPeerAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "connectPeerAssociation",
      connectPeerAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ) extends zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly {
    override val connectPeerAssociation: Optional[
      zio.aws.networkmanager.model.ConnectPeerAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.connectPeerAssociation())
      .map(value =>
        zio.aws.networkmanager.model.ConnectPeerAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.AssociateConnectPeerResponse
  ): zio.aws.networkmanager.model.AssociateConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}
